#ifndef __SAVE_RAW_IMAGE_H__
#define __SAVE_RAW_IMAGE_H__

#include <stdint.h>
#include <stdbool.h>
#include <linux/v4l2-subdev.h>
#include <linux/videodev2.h>

#define DEV_VID_DEF "/dev/video0"
#define SDEV_CAM_DEF "/dev/v4l-subdev1"
#define SDEV_COL_DEF "/dev/v4l-subdev2"
#define SDEV_IPU_DEF "/dev/v4l-subdev0"

#define FMT_DEF "Y8"
#define STD_DEF "PAL"
#define GAIN_DEF 64

#define NAME_FMT_DEF "image"
#define NAME_END ".raw"
#define STR_B_LEN 512

#define EXP_TIME_MIN 32
#define GAIN_NUMB 5

#define V4L2_CID_GAIN_RED	    0x9a1001
#define V4L2_CID_GAIN_GREEN_R	0x9a1002
#define V4L2_CID_GAIN_GREEN_B	0x9a1003
#define V4L2_CID_GAIN_BLUE	    0x9a1004
#define V4L2_CID_BINNING	    0x9a1005

#define I2C_PATH "/sys/bus/i2c/drivers/"

enum crops_stat { LEFT = 0, TOP = 1, WIDTH = 2, HEIGHT = 3 };

enum gain_stat { GLOBAL = 0, RED = 1, YELLOW = 2, CYAN = 3, BLUE = 4 };

struct vid_std {
	char name[STR_B_LEN];
	v4l2_std_id code;
};

struct pm_format {
	char name[STR_B_LEN];
	uint32_t pfmt_code;
	enum v4l2_mbus_pixelcode mfmt_code;
};

struct cam_reg {
    uint32_t address;
    uint64_t reg;
    uint64_t reg_state;
};

struct sub_devices {
	char sdev_cam[STR_B_LEN];
	char sdev_ipu[STR_B_LEN];
	char sdev_colshift[STR_B_LEN];

	uint32_t gain_global;
	uint32_t gain_red;
	uint32_t gain_yellow;
	uint32_t gain_cyan;
	uint32_t gain_blue;
	bool is_grey;

	int32_t crops[4];

	int32_t res_x;
	int32_t res_y;

	bool binning;
	bool flip_h;
	bool flip_v;

    struct cam_reg reg_state;
};

struct sri_args {
	char vdev[STR_B_LEN];
	struct sub_devices sdevs;

	struct pm_format format;

	char name_fmt[STR_B_LEN];

	uint32_t save_frames;
	uint32_t drop_frames;

	struct buffer *buffs;
	uint32_t buf_size;

	bool set_reg;
	char reg_file[STR_B_LEN];
    
    bool set_std;
	struct vid_std v_std;

	uint8_t timeout_sec;
};

#endif				/* __SAVE_RAW_IMAGE_H__ */

