/*
 * =====================================================================================
 *
 *       Filename:  converter.c
 *
 *    Description:  converter c file to convert image formats
 *
 *        Version:  1.0
 *
 *         Author:  Alexander Aring, a.aring@phytec.de
 *        Company:  PHYTEC
 *
 * =====================================================================================
 */

#include "converter.h"

/*-----------------------------------------------------------------------------
 *  convert rgb565 16 bit to a 32 bit rgb88 value via call by reference.
 *-----------------------------------------------------------------------------*/
static int rgb565_to_rgb888_shift(__u16 rgb565, __u32 * rgb888)
{
	__u8 red, green, blue;
	red = (rgb565 & 0xF800) >> 8;
	green = (rgb565 & 0x7E0) >> 3;
	blue = (rgb565 & 0x1F) << 3;

	*rgb888 = 0;

	*rgb888 += red;
	*rgb888 <<= 8;

	*rgb888 += green;
	*rgb888 <<= 8;

	*rgb888 += blue;
	*rgb888 <<= 8;

	return 0;
}

/*-----------------------------------------------------------------------------
 *  converts rgb565 to rgb888, caller need to call free on rgb888 pointer.
 *  filesize will be the new size of rgb888 image.
 *-----------------------------------------------------------------------------*/
int rgb565_to_rgb888(__u16 * rgb565, size_t rgb565_size, __u32 * rgb888)
{
	int i;

	for (i = 0; i < (rgb565_size); i++)
		rgb565_to_rgb888_shift(rgb565[i], (rgb888 + i));

	return 0;
}
